@@ -5,6 +5,7 @@ from pdfminer.layout import LAParams
 from pdfminer.pdfpage import PDFPage
 from cStringIO import StringIO
 
+
 def to_text(path):
     rsrcmgr = PDFResourceManager()
     retstr = StringIO()
@@ -18,8 +19,11 @@ def to_text(path):
     password = ""
     maxpages = 0
     caching = True
-    pagenos=set()
-    for page in PDFPage.get_pages(fp, pagenos, maxpages=maxpages, password=password,caching=caching, check_extractable=True):
+    pagenos = set()
+    pages = PDFPage.get_pages(
+        fp, pagenos, maxpages=maxpages, password=password,
+        caching=caching, check_extractable=True)
+    for page in pages:
         interpreter.process_page(page)
     fp.close()
     device.close()
